#!/bin/sh
# rbinstall -- Install
#

# parameters ----------------------------------------------------

rbversion=4.2.3.1

# don't edit past this point ------------------------------------

echo ""

# check arguments -----------------------------------------------

case $# in
   0)
   ;;
   1)
   if test "$1" = "-v"; then
      echo "RedBack $rbversion Install"
      exit 0
   else
      Usage
   fi
   ;;
   *)
   Usage
   ;;
esac

# Find out how to suppress new-line in echo for this Unix machine.
if test "`echo -n`" = "-n"; then
   C='\c'
   N=
else
   C=
   N='-n'
fi

# Usage function ------------------------------------------------
Usage()
{
   cat <<EOM
Usage: $0 [-v]
EOM
   exit 1
}

# Embed Apache's GuessOS script here ----------------------------

# Apache's GuessOS is a command that echos a line to stdout.
# Hack it into a function, that returns $gs_out global:
#   i)  replace echo with gs_out=
#   ii) replace exit with return

gs_out=''
GuessOS()
{

# Simple OS/Platform guesser. Similar to config.guess but
# much, much smaller. Since it was developed for use with
# Apache, it follows under Apache's regular licensing
# with one specific addition: Any changes or additions
# to this script should be Emailed to the Apache
# group (apache@apache.org) in general and to
# Jim Jagielski (jim@jaguNET.com) in specific.
#
# Be as similar to the output of config.guess/config.sub
# as possible.

# First get uname entries that we use below

MACHINE=`(uname -m) 2>/dev/null` || MACHINE="unknown"
RELEASE=`(uname -r) 2>/dev/null` || RELEASE="unknown"
SYSTEM=`(uname -s) 2>/dev/null`  || SYSTEM="unknown"
VERSION=`(uname -v) 2>/dev/null` || VERSION="unknown"
PROCESSOR=`(uname -p) 2>/dev/null` || PROCESSOR="unknown"


# Now test for ISC and SCO, since it is has a braindamaged uname.
#
# We need to work around FreeBSD 1.1.5.1 
XREL=`uname -X 2>/dev/null | grep "^Release" | awk '{print $3}'`
if [ "x$XREL" != "x" ]; then
    if [ -f /etc/kconfig ]; then
	case "$XREL" in
	    4.0|4.1)
		    gs_out="${MACHINE}-whatever-isc4"; return 0
		;;
	esac
    else
	case "$XREL" in
	    3.2v4.2)
		gs_out="whatever-whatever-sco3"; return 0
		;;
	    3.2v5.0*)
		gs_out="whatever-whatever-sco5"; return 0
		;;
	    4.2MP)
		if [ "x$VERSION" = "x2.1.1" ]; then
		    gs_out="${MACHINE}-whatever-unixware211"; return 0
		else
		    gs_out="${MACHINE}-whatever-unixware2"; return 0
		fi
		;;
	    4.2)
		gs_out="whatever-whatever-unixware1"; return 0
		;;
	esac
    fi
fi
# Now we simply scan though... In most cases, the SYSTEM info is enough
#
case "${SYSTEM}:${RELEASE}:${VERSION}:${MACHINE}" in
    A/UX:*)
	gs_out="m68k-apple-aux3"; return 0
	;;

    AIX:*)
	gs_out="${MACHINE}-ibm-aix"; return 0
	;;

    dgux:*)
	gs_out="${MACHINE}${PROCESSOR}-dg-dgux"; return 0
	;;

    HI-UX:*)
	gs_out="${MACHINE}-hi-hiux"; return 0
	;;

    HP-UX:*)
	HPUXVER=`echo ${RELEASE}|sed -e 's/[^.]*.[0B]*//'`
	case "$HPUXVER" in
	    10.*)
		gs_out="${MACHINE}-hp-hpux10."; return 0
		;;
	    *)
		gs_out="${MACHINE}-hp-hpux"; return 0
		;;
	esac
	;;

    IRIX:*)
	gs_out="${MACHINE}-sgi-irix"; return 0
	;;

    IRIX64:*)
	gs_out="${MACHINE}-sgi-irix64"; return 0
	;;

    Linux:*)
	gs_out="${MACHINE}-whatever-linux"; return 0
	;;

    LynxOS:*)
	gs_out="${MACHINE}-lynx-lynxos"; return 0
	;;

    BSD/386:*:*:*486*|BSD/OS:*:*:*:*486*)
	gs_out="i486-whatever-bsdi"; return 0
	;;

    BSD/386:*|BSD/OS:*)
	gs_out="${MACHINE}-whatever-bsdi"; return 0
	;;

    FreeBSD:*:*:*486*)
	gs_out="i486-whatever-freebsd"; return 0
	;;

    FreeBSD:*)
	gs_out="${MACHINE}-whatever-freebsd"; return 0
	;;

    NetBSD:*:*:*486*)
	gs_out="i486-whatever-netbsd"; return 0
	;;

    NetBSD:*)
	gs_out="${MACHINE}-whatever-netbsd"; return 0
	;;

    OpenBSD:*)
	gs_out="${MACHINE}-whatever-openbsd"; return 0
	;;

    OSF1:*:*:*alpha*)
	gs_out="${MACHINE}-dec-osf"; return 0
	;;

    QNX:*)
	case "$VERSION" in
	    423)
		gs_out="${MACHINE}-qssl-qnx32"
		;;
	    *)
		gs_out="${MACHINE}-qssl-qnx"
		;;
	esac
	return 0
	;;

    Paragon*:*:*:*)
	gs_out="i860-intel-osf1"; return 0
	;;

    SunOS:5.*)
	gs_out="${MACHINE}-sun-solaris2"; return 0
	;;

    SunOS:*)
	gs_out="${MACHINE}-sun-sunos4"; return 0
	;;

    UNIX_System_V:4.*:*)
	gs_out="${MACHINE}-whatever-sysv4"; return 0
	;;

    *:4*:R4*:m88k)
	gs_out="${MACHINE}-whatever-sysv4"; return 0
	;;

    DYNIX/ptx:4*:*)
	gs_out="${MACHINE}-whatever-sysv4"; return 0
	;;

    *:4.0:3.0:3[34]?? | *:4.0:3.0:3[34]??,*)
	gs_out="i486-ncr-sysv4"; return 0
	;;

    ULTRIX:*)
	gs_out="${MACHINE}-unknown-ultrix"; return 0
	;;

    SINIX*)
	gs_out="${MACHINE}-sni-sysv4"; return 0
	;;

    machten:*)
       gs_out="${MACHINE}-tenon-${SYSTEM}"; return 0;
       ;;

    library:*)
	gs_out="${MACHINE}-ncr-sysv4"; return 0
	;;

    ConvexOS:*:11.0:*)
	gs_out="${MACHINE}-v11-${SYSTEM}"; return 0;
	;;

esac

#
# Ugg. These are all we can determine by what we know about
# the output of uname. Be more creative:
#

# Do the Apollo stuff first. Here, we just simply assume
# that the existance of the /usr/apollo directory is proof
# enough
if [ -d /usr/apollo ]; then
    gs_out="whatever-apollo-whatever"
    return 0
fi

# Now NeXT
ISNEXT=`hostinfo 2>/dev/null`
case "$ISNEXT" in
    *NeXT*)
	gs_out="whatever-next-nextstep"; return 0
	;;
esac

# At this point we gone through all the one's
# we know of: Punt

gs_out="${MACHINE}-whatever-${SYSTEM}|${RELEASE}|${VERSION}" 
return 0

}

# End Apache's GuessOS ------------------------------------------

GuessOS

gs_machid=
case "$gs_out" in
   *-ibm-aix*)
      gs_machid=aix
      if test "$VERSION" -lt 4; then
         cat <<EOM
WARNING!!! You are running AIX ${VERSION}.${RELEASE}
           RedBack was built for AIX 4.1
           It seems you need to upgrade your operating system.
EOM
      fi
      ;;
   *-dec-osf*)
      gs_machid=dec
      vv=`echo $RELEASE|cut -c2-`
      vv=`echo $vv|cut -d. -f1`
      if test "$vv" -eq 3; then
        gs_machid=dec3
      fi
      ;;
   *mc*-dg-dgux*)
      case "$RELEASE" in
         R4*)
            gs_machid=dg
            ;;
         5.3*)
            gs_machid=dg3
            ;;
         *)
            echo "Warning, don't know your release of DG/UX"
            echo uname -m
            uname -m
            echo uname -r
            uname -r
            echo uname -s
            uname -s
            echo uname -v
            uname -v
	    echo uname -X
            uname -X
            ;;
      esac
      ;;
   *Pentium*-dg-dgux*)
      gs_machid=dgi
      ;;
   *-hp-hpux*)
      gs_machid=hp
      ;;
   *-sgi-irix*)
      gs_machid=irx
      ;;
   *-linux*)
      gs_machid=lnx
      ;;
   *-sco5*)
      gs_machid=sco
      ;;
   *-sni-sysv4*)
      gs_machid=snx
      ;;
   *-solaris2*)
      gs_machid=sun
      ;;
   m*-whatever-sysv4*)
      gs_machid=mot
      ;;
   i*-whatever-sysv4*)
      gs_machid=seq
      ;;
   *-DYNIX*)
      gs_machid=seq
      ;;
   *-ncr-sysv4*)
      gs_machid=ncr
      ;;
   *-*-unisys*)
      gs_machid=uni
      ;;
   *-*-UnixWare*)
      gs_machid=uxw
      ;;
   *)
      echo "Warning, don't know your platform $gs_out"
      echo uname -m
      uname -m
      echo uname -r
      uname -r
      echo uname -s
      uname -s
      echo uname -v
      uname -v
      echo uname -X
      uname -X
      ;;
esac

# ---------------------------------------------------------------
# main program
#

# stop shell from interfering with permissions when untaring
umask 0

# This script (rbinstall) and its associated tar-ball (rb*.tar)
# are put into scratchdir from tape (or via ftp).
# Once that's done, the script is identical for both methods.
# Note that it is an error if there is more than one rb*.tar
# in the scratch directory.

cat <<EOM
RedBack Minimum Gateway $rbversion Install

It is strongly recommended that, before installation, you create a
non-root userid specifically to install and administer RedBack.

Do not install RedBack as root.

EOM

# check userid is not super-user
myuid=`id|sed -e 's/uid=//' -e 's/(.*//'`
if test "$myuid" -eq 0; then
   cat <<EOM
*****************************************************************

WARNING!!!

I see you are logged in with super-user permissions.
Please don't run this install script with super-user permissions.
If you wish to run the RedBack Gateway as root see the 
Administering Redback manual for more information.

Aborting install.

*****************************************************************

EOM
   exit 1
fi

# Find out some basic stuff -------------------------------------

# Find logged in user name, zusername
# LOGNAME is defined by POSIX.1, XPG3, SVR4 and 4.3+BSD
# Ultrix uses env. vble. USER instead of LOGNAME
if test -z "$LOGNAME"; then
   if test -z "$USER"; then
      zusername=`(logname) 2>/dev/null`
      if test -z "$zusername"; then
         zusername=`who am i | sed -e 's/ .*//' -e 's/.*!//'`
      fi
   else
      zusername=$USER
   fi
else
   zusername=$LOGNAME
fi
if test -z "$zusername"; then
   echo "Error: can't find your username"
   exit 1
fi

# Find host name, zhostname
zhostname=`(hostname) 2>/dev/null`
if test -z "$zhostname"; then
   zhostname=`(uuname -l) 2>/dev/null`
   if test -z "$zhostname"; then
      zhostname=`uname -n`
   fi
fi
if test -z "$zhostname"; then
   echo "Sorry, couldn't find your host name, giving up."
   exit 1
fi
#echo "Assuming hostname=$zhostname"
# Trim domain name.
case "$zhostname" in
   *.*)
   zdomain=`expr "X$zhostname" : "X[^.]*\(\..*\)"`
   zhostname=`expr "X$zhostname" : "X\([^.]*\)\."`
   #echo "Trimming domain name from hostname."
   #echo "hostname is now $zhostname (domain name is $zdomain)"
   ;;
esac

# ---------------------------------------------------------------

# set scratchdir to current dir
scratchdir=`pwd`
rbtarball=$scratchdir/rb.tar
# if $scratchdir/rb.tar exists, use that.
if test -f "$rbtarball"; then
   if test -r "$rbtarball"; then
      :
   else
      echo "error: $rbtarball is not readable"
      exit 1
   fi
else
   # rb.tar not found -- try to find another one.
   ntarballs=`ls $scratchdir/rb*.tar | wc -l`
   if test "$ntarballs" -eq 0; then
      echo "error: no file of form rb*.tar found in $scratchdir"
      exit 1
   elif test "$ntarballs" -eq 1; then
      rbtarball=`ls $scratchdir/rb*.tar`
   else
      echo "error: more than one file of form rb*.tar found in $scratchdir"
      echo "       copy the one that you want to use to rb.tar"
      exit 1
   fi
fi


# get install directory
echo ""
# setting `pwd` as install dir

rbdir=`pwd`
echo "Default '$rbdir' accepted."


# ---------------------------------------------------------------
# adding at the all entries of rgw.ini

#_------------------------------------------------------------------

if cd "$rbdir"; then
   :
else
   echo "error: cd $rbdir failed!"
   exit 1
fi

echo ""
echo "Installing RedBack from file $rbtarball"
# STEP2 : extract TAR
echo ""
echo $N "Extracting...$C"

if tar xf "$rbtarball" > /dev/null; then
   echo "tar succeeded."
else
   echo "tar failed."
   exit 1
fi

#os platform selection code
savefile=`pwd`/install.tmp

#------------------------------------------------------------------
# STEP 3: select OS 
case "$gs_machid" in
      aix)
          echo "Platform is aix, getting library ..."
 	  cp `pwd`/gateway/rgw/os/aix/bin/libjrgw.so  .
          ;;
      dec)
          echo "Platform is dec, getting library ..."
	  cp `pwd`/gateway/rgw/os/dec/bin/libjrgw.so  .
          ;;
         
      dg)
	   echo "Platform dg is not supported for this install !"
           echo "Aborting."
           exit 1
       ;;

      dgi)
          echo "Platform is dgi, getting library ..."
 	  cp `pwd`/gateway/rgw/os/dgi/bin/libjrgw.so  .
        ;;

      hp)
          echo "Platform is hp, getting library ..."
	  cp `pwd`/gateway/rgw/os/hp/bin/libjrgw.so  .
 	  ;;
      irx)
 	 echo "Platform irx is not supported for this install !"
         echo "Aborting."
         exit 1
        ;;

      lnx)
          echo "Platform is lnx, getting library ..."
	  cp `pwd`/gateway/rgw/os/lnx/bin/libjrgw.so  .
	 ;;

      ncr)
	  echo "Platform ncr is not supported for this install !"
          echo "Aborting."
          exit 1
	 ;;

      sco)
 	  echo "Platform ncr is not supported for this install !"
          echo "Aborting."
          exit 1
        ;;
      seq)
          echo "Platform seq is not supported for this install !"
          echo "Aborting."
          exit 1
        ;;

      snx)
 	  echo "Platform snx is not supported for this install !"
          echo "Aborting."
          exit 1
        ;;

      sun)
          echo "Platform is sun, getting library ..."
 	  cp `pwd`/gateway/rgw/os/sun/bin/libjrgw.so  .
	;;

      uxw)
 	  echo "Platform uxw is not supported for this install !"
          echo "Aborting."
          exit 1
        ;;
esac

# STEP4 : create rgw.ini
# create rgw.ini
echo "done."

fname="`pwd`/rgw.ini"
echo $N "Creating $fname...$C"
echo " "
echo " "
echo "Please enter the RedBack account name " >&2
read accname
echo "Please enter the port number for $accname " >&2
read portnum
echo "Please enter the host address where Redback RBO Server is installed " >&2
read hoststring

cat > $fname <<!GROK!THIS!
$accname   $hoststring:$portnum

[LogLevel]
panic=1
err=1
wrn=0
inf=0
init=1
trace=0
verb=0
big=0

!GROK!THIS!
chmod 666 $fname
echo "done."
echo "Note: You will need enter root password to copy"
echo "rgw.ini to /etc dirctory and libjrgw.so in /usr/lib direcory "

echo $N "do you want to copy files manually? [Y|n] > $C" >&2
      read ans
      if test -z "$ans" ; then
         ans=Y
         echo "Default '$ans' accepted."
      fi
      case $ans in
         y|Y)
            echo "Please copy rgw.ini to /etc dirctory  "
            echo "Please copy libjrgw.so to /usr/lib direcory "
             ;;
         N|n)
            #echo $N "Please enter root user password  > $C" >&2
            #read password
            #echo $password
            #su
            echo "Copying rgw.ini to /etc . Please enter root user password"
	    su root "-c cp rgw.ini /etc/rgw.ini" 
             echo "Copying libjrgw.so /usr/lib. Please enter root user password "
            su root "-c cp libjrgw.so /usr/lib" 
            rm -rf gateway
            rm rgw.ini
            rm libjrgw.so
            ;;
         *)
            continue
         ;;
      esac

cat <<EOM


===================================================================
Congratulations!

RedBack Minimum Gateway $rbversion has been successfully installed

===================================================================

EOM

exit 0






